@@ -1,5 +1,5 @@
 package Games::Solitaire::BlackHole::Solver::App;
-$Games::Solitaire::BlackHole::Solver::App::VERSION = '0.0.4';
+$Games::Solitaire::BlackHole::Solver::App::VERSION = '0.2.0';
 use strict;
 use warnings;
 
@@ -15,29 +15,30 @@ sub new
     return bless {}, $class;
 }
 
-my @ranks = ("A", 2 .. 9, qw(T J Q K));
-my %ranks_to_n = (map { $ranks[$_] => $_ } 0 .. $#ranks);
+my @ranks = ( "A", 2 .. 9, qw(T J Q K) );
+my %ranks_to_n = ( map { $ranks[$_] => $_ } 0 .. $#ranks );
 
-my $card_re_str = '[' . join("", @ranks) . '][HSCD]';
-my $card_re = qr{$card_re_str};
+my $card_re_str = '[' . join( "", @ranks ) . '][HSCD]';
+my $card_re     = qr{$card_re_str};
 
 sub _get_rank
 {
-    return $ranks_to_n{substr(shift(), 0, 1)};
+    return $ranks_to_n{ substr( shift(), 0, 1 ) };
 }
 
 sub _calc_lines
 {
     my $filename = shift;
 
-    if ($filename eq "-")
+    if ( $filename eq "-" )
     {
         return [<STDIN>];
     }
     else
     {
         open my $in, "<", $filename
-            or die "Could not open $filename for inputting the board lines - $!";
+            or die
+            "Could not open $filename for inputting the board lines - $!";
         my @lines = <$in>;
         close($in);
         return \@lines;
@@ -48,21 +49,22 @@ sub run
 {
     my $output_fn;
 
-    my ($help, $man, $version);
+    my ( $help, $man, $version );
 
     GetOptions(
         "o|output=s" => \$output_fn,
-        'help|h|?' => \$help,
-        'man' => \$man,
-        'version' => \$version,
+        'help|h|?'   => \$help,
+        'man'        => \$man,
+        'version'    => \$version,
     ) or pod2usage(2);
 
     pod2usage(1) if $help;
-    pod2usage(-exitstatus => 0, -verbose => 2) if $man;
+    pod2usage( -exitstatus => 0, -verbose => 2 ) if $man;
 
     if ($version)
     {
-        print "black-hole-solve version $Games::Solitaire::BlackHole::Solver::App::VERSION\n";
+        print
+"black-hole-solve version $Games::Solitaire::BlackHole::Solver::App::VERSION\n";
         exit(0);
     }
 
@@ -70,23 +72,23 @@ sub run
 
     my $output_handle;
 
-    if (defined($output_fn))
+    if ( defined($output_fn) )
     {
-        open ($output_handle, ">", $output_fn)
+        open( $output_handle, ">", $output_fn )
             or die "Could not open '$output_fn' for writing";
     }
     else
     {
-        open ($output_handle, ">&STDOUT");
+        open( $output_handle, ">&STDOUT" );
     }
 
-    my @lines = @{_calc_lines($filename)};
+    my @lines = @{ _calc_lines($filename) };
     chomp(@lines);
 
     my $found_line = shift(@lines);
 
     my $init_foundation;
-    if (my ($card) = $found_line =~ m{\AFoundations: ($card_re)\z})
+    if ( my ($card) = $found_line =~ m{\AFoundations: ($card_re)\z} )
     {
         $init_foundation = _get_rank($card);
     }
@@ -95,25 +97,28 @@ sub run
         die "Could not match first foundation line!";
     }
 
-    my @board_cards = map { [split/\s+/, $_]} @lines;
-    my @board_values = map { [map { _get_rank($_) } @$_ ] } @board_cards;
+    my @board_cards  = map { [ split /\s+/, $_ ] } @lines;
+    my @board_values = map {
+        [ map { _get_rank($_) } @$_ ]
+    } @board_cards;
 
     my $init_state = "";
 
-    vec($init_state, 0, 8) = $init_foundation;
+    vec( $init_state, 0, 8 ) = $init_foundation;
 
-    foreach my $col_idx (0 .. $#board_values)
+    foreach my $col_idx ( 0 .. $#board_values )
     {
-        vec($init_state, 4+$col_idx, 2) = scalar(@{$board_values[$col_idx]});
+        vec( $init_state, 4 + $col_idx, 2 ) =
+            scalar( @{ $board_values[$col_idx] } );
     }
 
     # The values of %positions is an array reference with the 0th key being the
     # previous state, and the 1th key being the column of the move.
-    my %positions = ($init_state => []);
+    my %positions = ( $init_state => [] );
 
     my @queue = ($init_state);
 
-    my %is_good_diff = (map { $_ => 1 } (1, $#ranks));
+    my %is_good_diff = ( map { $_ => 1 } ( 1, $#ranks ) );
 
     my $verdict = 0;
 
@@ -121,14 +126,14 @@ sub run
         my $final_state = shift;
 
         my $state = $final_state;
-        my ($prev_state, $col_idx);
+        my ( $prev_state, $col_idx );
 
         my @moves;
-        while (($prev_state, $col_idx) = @{$positions{$state}})
+        while ( ( $prev_state, $col_idx ) = @{ $positions{$state} } )
         {
             push @moves,
-                $board_cards[$col_idx][vec($prev_state, 4+$col_idx, 2)-1]
-                ;
+                $board_cards[$col_idx]
+                [ vec( $prev_state, 4 + $col_idx, 2 ) - 1 ];
         }
         continue
         {
@@ -137,38 +142,42 @@ sub run
         print {$output_handle} map { "$_\n" } reverse(@moves);
     };
 
-    QUEUE_LOOP:
-    while (my $state = pop(@queue))
+QUEUE_LOOP:
+    while ( my $state = pop(@queue) )
     {
         # The foundation
-        my $fnd = vec($state, 0, 8);
+        my $fnd      = vec( $state, 0, 8 );
         my $no_cards = 1;
 
         # my @debug_pos;
-        foreach my $col_idx (0 .. $#board_values)
+        foreach my $col_idx ( 0 .. $#board_values )
         {
-            my $pos = vec($state, 4+$col_idx, 2);
+            my $pos = vec( $state, 4 + $col_idx, 2 );
+
             # push @debug_pos, $pos;
             if ($pos)
             {
                 $no_cards = 0;
 
-                my $card = $board_values[$col_idx][$pos-1];
-                if (exists($is_good_diff{
-                    ($card - $fnd) % scalar(@ranks)
-                }))
+                my $card = $board_values[$col_idx][ $pos - 1 ];
+                if (
+                    exists(
+                        $is_good_diff{ ( $card - $fnd ) % scalar(@ranks) }
+                    )
+                    )
                 {
                     my $next_s = $state;
-                    vec($next_s, 0, 8) = $card;
-                    vec($next_s, 4+$col_idx, 2)--;
-                    if (! exists($positions{$next_s}))
+                    vec( $next_s, 0, 8 ) = $card;
+                    vec( $next_s, 4 + $col_idx, 2 )--;
+                    if ( !exists( $positions{$next_s} ) )
                     {
-                        $positions{$next_s} = [$state, $col_idx];
-                        push(@queue, $next_s);
+                        $positions{$next_s} = [ $state, $col_idx ];
+                        push( @queue, $next_s );
                     }
                 }
             }
         }
+
         # print "Checking ", join(",", @debug_pos), "\n";
         if ($no_cards)
         {
@@ -179,17 +188,17 @@ sub run
         }
     }
 
-    if (! $verdict)
+    if ( !$verdict )
     {
         print {$output_handle} "Unsolved!\n";
     }
 
-    if (defined($output_fn))
+    if ( defined($output_fn) )
     {
         close($output_handle);
     }
 
-    exit(! $verdict);
+    exit( !$verdict );
 }
 
 
@@ -208,7 +217,7 @@ implemented as a class to solve the Black Hole solitaire.
 
 =head1 VERSION
 
-version 0.0.4
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -277,7 +286,7 @@ More information about Black Hole Solitaire can be found at:
 
 =head1 VERSION
 
-version 0.0.4
+version 0.2.0
 
 =head1 METHODS
 
@@ -295,7 +304,7 @@ The Black Hole Solitaire Solvers homepage is at
 L<http://www.shlomifish.org/open-source/projects/black-hole-solitaire-solver/>
 and one can find there an implementation of this solver as a C library (under
 the same licence), which is considerably faster and consumes less memory,
-and has had some otehr impovements.
+and has had some other improvements.
 
 =head1 AUTHOR
 
@@ -358,12 +367,6 @@ feature.
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Games::Solitaire::BlackHole::Solver
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -377,7 +380,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Games-Solitaire-BlackHole-Solver>
+L<https://metacpan.org/release/Games-Solitaire-BlackHole-Solver>
 
 =item *
 
@@ -413,14 +416,6 @@ L<http://cpanratings.perl.org/d/Games-Solitaire-BlackHole-Solver>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Games-Solitaire-BlackHole-Solver>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -431,7 +426,7 @@ L<http://cpants.cpanauthors.org/dist/Games-Solitaire-BlackHole-Solver>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/G/Games-Solitaire-BlackHole-Solver>
 
